/*
** Copyright 1998 - 2000 Double Precision, Inc.  See COPYING for
** distribution information.
*/

/* $Id: acconfig.h,v 1.13 2002/05/08 02:23:46 mrsam Exp $ */

/* Whether we must provide a prototype for crypt() */
#undef	NEED_CRYPT_PROTOTYPE

/* Whether we have the crypt function */
#undef	HAVE_CRYPT

/* Whether we have the MD5 library available */
#undef	HAVE_MD5LIB

/* Whether we have the SHA1 library available */
#undef	HAVE_SHA1LIB

/* Whether we have the HMAC library available */
#undef	HAVE_HMACLIB

/* Location of the userdb database */
#undef	USERDB

/* This macro is used to build the list of SASL modules */
#undef	SASL_LIST

/* Whether -lvpopmail has the open_smtp_relay() function */
#undef HAVE_OPEN_SMTP_RELAY

/* Whether -lvpopmail has the vlogauth() function */
#undef HAVE_VLOGAUTH

/* Whether we have the expect() utility */
#undef HAVE_EXPECT

/* Whether password changing should be enabled */
#undef AUTHCHANGEPASS

/* Whether we have ldap_start_tls_s() */
#undef HAVE_LDAP_TLS

/* Whether we have ldap_result2error */
#undef HAVE_LDAP_RESULT2ERROR
